==> mozc_1.3.975.102.orig.tar.gz: mozc-1.3.975.102/dictionary/file/codec.h <==
// Copyright 2010-2012, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// Defines codec for dictionary file

#ifndef MOZC_DICTIONARY_FILE_CODEC_H_
#define MOZC_DICTIONARY_FILE_CODEC_H_

#include "dictionary/file/codec_interface.h"

#include <vector>

#include "base/base.h"
#include "dictionary/file/section.h"

namespace mozc {
class OutputFileStream;


class DictionaryFileCodec : public DictionaryFileCodecInterface {
 public:
  DictionaryFileCodec();

  virtual ~DictionaryFileCodec();

  virtual void WriteSections(const vector<DictionaryFileSection> &sections,
                             OutputFileStream *ofs) const;

  virtual bool ReadSections(const char *image, int length,
                            vector<DictionaryFileSection> *sections) const;

  virtual string GetSectionName(const string &name) const;

 private:
  void WriteHeader(OutputFileStream *ofs) const;

  void WriteSection(const DictionaryFileSection &section,
                    OutputFileStream *ofs) const;

  // Magic value for simple file validation
  const int filemagic_;

  DISALLOW_COPY_AND_ASSIGN(DictionaryFileCodec);
};

}  // namespace mozc
#endif  // MOZC_DICTIONARY_FILE_CODEC_H_

==> mozc_1.5.1090.102.orig.tar.gz: mozc-1.5.1090.102/dictionary/file/codec.h <==
// Copyright 2010-2012, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// Defines codec for dictionary file

#ifndef MOZC_DICTIONARY_FILE_CODEC_H_
#define MOZC_DICTIONARY_FILE_CODEC_H_

#include "dictionary/file/codec_interface.h"

#include <vector>

#include "base/base.h"
#include "dictionary/file/section.h"

namespace mozc {


class DictionaryFileCodec : public DictionaryFileCodecInterface {
 public:
  DictionaryFileCodec();

  virtual ~DictionaryFileCodec();

  virtual void WriteSections(const vector<DictionaryFileSection> &sections,
                             ostream *ofs) const;

  virtual bool ReadSections(const char *image, int length,
                            vector<DictionaryFileSection> *sections) const;

  virtual string GetSectionName(const string &name) const;

 private:
  void WriteHeader(ostream *ofs) const;

  void WriteSection(const DictionaryFileSection &section,
                    ostream *ofs) const;

  // Magic value for simple file validation
  const int filemagic_;

  DISALLOW_COPY_AND_ASSIGN(DictionaryFileCodec);
};

}  // namespace mozc
#endif  // MOZC_DICTIONARY_FILE_CODEC_H_
